(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     20486,        591]*)
(*NotebookOutlinePosition[     45956,       1435]*)
(*  CellTagsIndexPosition[     45912,       1431]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Procedural Program Verification  in Theorema",
  FontSize->30]], "SectionFirst",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["Special Constructs: ", "Section"],

Cell[BoxData[
    \(Program, Specification, Execute\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Procedural language", "Section"],

Cell[TextData[StyleBox["Example: Division of two natural numbers",
  FontSlant->"Italic"]], "Text"],

Cell[BoxData[
    \(Specification["\<Division\>", \[IndentingNewLine]\t\t\t\ \ \ \ Div[\(\(\
\[DownArrow]\)\(x\)\), \ \(\(\[DownArrow]\)\(y\)\), \ \(\(\[UpArrow]\)\(rem\)\
\), \ \(\(\[UpArrow]\)\(quo\)\)], \[IndentingNewLine]\t\t\ \ \ \ \ \ \ \ \ \ \
\ \ \ Pre \[Rule] \((\((x \[GreaterEqual] 0)\) \[And] \((y > 
                0)\))\), \[IndentingNewLine]\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \
Post \[Rule] \((\((quo*y + rem = x)\) \[And] \((0 \[LessEqual] rem < 
                y)\))\)]\)], "Input",
  CellLabel->"TS_In[88]:="],

Cell[BoxData[
    \(Program["\<Division\>", \[IndentingNewLine]\t\t\
Div[\(\(\[DownArrow]\)\(x\)\), \ \(\(\[DownArrow]\)\(y\)\), \ \
\(\(\[UpArrow]\)\(rem\)\), \ \(\(\[UpArrow]\)\(quo\)\)], \[IndentingNewLine]\t\
\ \ \ \ \ \ \ \ \ quo := 0; \[IndentingNewLine]\t\trem := 
        x; \[IndentingNewLine]\t\tWHILE[
        y \[LessEqual] rem, \[IndentingNewLine]\t\t\t\t\trem := 
          rem - y; \ \[IndentingNewLine]\t\t\t\t\tquo := 
          quo + 1, \[IndentingNewLine]\t\t\tInvariant \[Rule] \((\((quo*y + 
                    rem = x)\) \[And] \((0 \[LessEqual] rem)\) \[And] \((0 < 
                  y)\))\), \[IndentingNewLine]\t\t\tTerminationTerm \[Rule] 
          rem], \[IndentingNewLine]\t\tSpecification \[Rule] 
        Specification["\<Division\>"]]\)], "Input",
  CellLabel->"TS_In[89]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpretor", "Section"],

Cell[TextData[StyleBox["Example: executing the above program",
  FontSlant->"Italic"]], "Text"],

Cell[BoxData[
    \(Clear[rm, qt]\)], "Input",
  CellLabel->"TS_In[36]:="],

Cell[BoxData[
    \(Execute[Div[55, \ 14, \ rm, \ qt]]\)], "Input",
  CellLabel->"TS_In[37]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({rm, qt}\)], "Input",
  CellLabel->"TS_In[38]:="],

Cell[BoxData[
    \({13, 3}\)], "Output",
  CellLabel->"TS_Out[38]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification Condition Generator", "Section"],

Cell[TextData[StyleBox["Example: generating the verification conditions for  \
the above program",
  FontSlant->"Italic"]], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VCG[Program["\<Division\>"], Specification["\<Division\>"]]\)], "Input",\

  CellLabel->"TS_In[90]:="],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
        "Lemma", \(\(\ \)\((\)\), "Division", \(\()\)\(:\)\(\n\)\), GridBox[{
              {
                RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["rem",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["quo",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}]}
              },
            ColumnAlignments->{Left}], "\n", 
          RowBox[{\((WHILE . Inv + Term)\), "\t", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          RowBox[{
                            StyleBox["quo",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox["y",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "+", 
                          StyleBox["rem",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "=", 
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "\[And]", 
                    RowBox[{"0", "\[LessEqual]", 
                      StyleBox["rem",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "\[And]", 
                    RowBox[{"0", "<", 
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "\[And]", 
                RowBox[{
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[LessEqual]", 
                  StyleBox["rem",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[And]", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["rem",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "=", "T1"}], ")"}]}], "\[Implies]", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                StyleBox["quo",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "+", "1"}], ")"}], "*", 
                            StyleBox["y",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "+", 
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox["rem",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "-", 
                              StyleBox["y",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], ")"}]}], "=", 
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "\[And]", 
                    RowBox[{"0", "\[LessEqual]", 
                      RowBox[{
                        StyleBox["rem",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "-", 
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], "\[And]", 
                    RowBox[{"0", "<", 
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    StyleBox["rem",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "-", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "<", "T1"}]}]}]}], 
          "\n", \((WHILE . Final)\), "\t", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        StyleBox["quo",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox["rem",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "=", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "\[And]", 
                RowBox[{"0", "\[LessEqual]", 
                  StyleBox["rem",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[And]", 
                RowBox[{"0", "<", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "\[And]", 
            RowBox[{
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[NotLessEqual]", 
              StyleBox["rem",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]}], "\[Implies]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["quo",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox["rem",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "=", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "\[And]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"0", "\[LessEqual]", 
                StyleBox["rem",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                StyleBox["rem",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "<", 
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}]}]}], TraditionalForm], "\n", 
    FormBox[
      RowBox[{
        RowBox[{\((WHILE . Term)\), "\t", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        StyleBox["quo",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox["rem",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "=", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "\[And]", 
                RowBox[{"0", "\[LessEqual]", 
                  StyleBox["rem",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[And]", 
                RowBox[{"0", "<", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "\[And]", 
            RowBox[{
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[LessEqual]", 
              StyleBox["rem",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]}], "\[Implies]", 
        RowBox[{
          StyleBox["rem",
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[GreaterEqual]", "0"}]}], 
      TraditionalForm], "\n", 
    FormBox[
      RowBox[{\((Init)\), "\t", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", "0"}], "\[And]", 
            RowBox[{
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ">", "0"}]}], "\[Implies]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"0", "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "=", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "\[And]", 
            RowBox[{"0", "\[LessEqual]", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[And]", 
            RowBox[{"0", "<", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]}]}], TraditionalForm]}], "Input",
  CellLabel->"TS_Out[90]//TraditionalForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic Principle", "Section"],

Cell[TextData[{
  StyleBox["{P}\t\t\t\t\t\t\t   {P}\n",
    FontSize->14],
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)],
    FontSize->14],
  StyleBox["\t\t\t\t\t\t\t         ",
    FontSize->14],
  StyleBox["\[LeftArrow]",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`wp\_n\)],
    FontSize->10],
  StyleBox["    \n   ",
    FontSize->14],
  StyleBox["\[LeftArrow]?\t\t\t\t\t\t\t\t\t              ",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)],
    FontSize->14],
  StyleBox["\n",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)],
    FontSize->14],
  StyleBox["\t\t\t\t\t\t\t         ",
    FontSize->14],
  StyleBox["\[LeftArrow]",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`wp\_\(n - 1\)\)],
    FontSize->10],
  StyleBox["   \n   ",
    FontSize->14],
  StyleBox["\[LeftArrow]?\t\t\t     ",
    FontSize->10],
  StyleBox["\[Rule]Weakest Precond.Strategy",
    FontSize->14],
  StyleBox["\t\t   ",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)],
    FontSize->14],
  StyleBox["\t   \[UpArrow] ",
    FontSize->14],
  "+ ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              StyleBox["Verification",
                FontSize->10]},
            {
              StyleBox["conditions",
                FontSize->10]}
            }], TraditionalForm]],
    FontSize->14],
  "                   .                                                       \
                                                                              \
",
  StyleBox["\n  \[VerticalEllipsis]\t\t\t\t\t\t\t\t\t                \
\[VerticalEllipsis]\n   \[LeftArrow]?\t\t                                     \
                                                                 ",
    FontSize->10],
  StyleBox["\[LeftArrow] ",
    FontSize->14],
  Cell[BoxData[
      \(TraditionalForm\`wp\_1\)],
    FontSize->10],
  StyleBox["  \t",
    FontSize->14],
  StyleBox["\n",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)],
    FontSize->14],
  StyleBox["\t\t\t\t\t\t\t ",
    FontSize->14],
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)],
    FontSize->14],
  StyleBox[" \n{Q}\t\t\t\t\t\t\t     {Q}\n\t\t\t\t\t\t      \n\t\t\t\t\t\t    \
  \t   ",
    FontSize->14],
  Cell[BoxData[
      \(TraditionalForm\`P \[Implies] wp\_n\)],
    FontSize->14]
}], "Text"]
}, Open  ]],

Cell["Uses first-order predicate logic!", "Text"],

Cell["", "Section"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Further work: While loop: generate invariant using \
combinatorics",
  FontSize->12]], "Subsection",
  CellMargins->{{17.375, Inherited}, {Inherited, Inherited}}],

Cell["Example: Integer division", "Text",
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(quo := 
        0;\)\), "\[IndentingNewLine]", 
    \(\t\t\(rem := x;\)\), "\[IndentingNewLine]", 
    \(\t\tWHILE[
      y \[LessEqual] rem, \[IndentingNewLine]\t\t\t\t\trem := 
        rem - y; \ \[IndentingNewLine]\t\t\t\t\tquo := quo + 1]\)}], "Input"],

Cell["Recursion equations:", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(\(\ \)\(quo\_0 = \
\(0\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ r\
em\_0 = x\)\)\)\)], "Input"],

Cell[BoxData[
    \(quo\_\(k + 1\) = \(quo\_k + 
          1\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ rem\_\(k + 1\) := 
        rem\_k - y\)\)], "Input"],

Cell["Explicit equations (by using combinatorics):", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(quo\_k = \
\(k\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ r\
em\_k = x - k*y\)\)], "Input"],

Cell["Eliminate k:", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(rem = x - quo*y\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
AutoGeneratedPackage->None,
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{1016, 696},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "npopov", \
"Verifications"}, "Proiect_sem.nb.ps", CharacterEncoding -> "WindowsANSI"],
"Magnification"->1},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\

Modify the definitions below to change the default appearance of all cells in \

a given style.

Make modifications to any definition using commands in the Format menu.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\

The options defined for the style below will be used at the Notebook level.
\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->36],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\

The cells in this section define styles used for input and output to the 
kernel.  Be careful when modifying, renaming, or removing these styles, 
because the front end associates special meanings with these style names.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\

The cells below define styles useful for making hypertext ButtonBoxes.  The 
\"Hyperlink\" style is for links within the same Notebook, or between 
Notebooks.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\

The following styles are for linking automatically to the on-line help 
system.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\

The cells below define styles that define standard ButtonFunctions, for use 
in palette buttons.
\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\

The following styles are useful for numbered equations, figures, etc.  They 
automatically give the cell a FrameLabel containing a reference to a 
particular counter, and also increment that counter.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 136, 2, 114, "SectionFirst"],

Cell[CellGroupData[{
Cell[1888, 58, 39, 0, 84, "Section"],
Cell[1930, 60, 64, 1, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2031, 66, 38, 0, 84, "Section"],
Cell[2072, 68, 99, 1, 39, "Text"],
Cell[2174, 71, 524, 8, 140, "Input"],
Cell[2701, 81, 809, 13, 296, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3547, 99, 30, 0, 84, "Section"],
Cell[3580, 101, 95, 1, 39, "Text"],
Cell[3678, 104, 74, 2, 62, "Input"],
Cell[3755, 108, 95, 2, 62, "Input"],

Cell[CellGroupData[{
Cell[3875, 114, 69, 2, 62, "Input"],
Cell[3947, 118, 69, 2, 42, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4065, 126, 51, 0, 84, "Section"],
Cell[4119, 128, 131, 2, 39, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4299, 136, 122, 3, 62, "Input"],
Cell[4424, 141, 12203, 304, 236, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16664, 450, 34, 0, 84, "Section"],
Cell[16701, 452, 2369, 86, 328, "Text"]
}, Open  ]],
Cell[19085, 541, 49, 0, 39, "Text"],
Cell[19137, 543, 19, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[19181, 547, 186, 3, 58, "Subsection"],
Cell[19370, 552, 63, 1, 39, "Text"],
Cell[19436, 555, 315, 6, 147, "Input"],
Cell[19754, 563, 58, 1, 39, "Text"],
Cell[19815, 566, 153, 3, 43, "Input"],
Cell[19971, 571, 158, 3, 43, "Input"],
Cell[20132, 576, 82, 1, 39, "Text"],
Cell[20217, 579, 149, 3, 43, "Input"],
Cell[20369, 584, 50, 1, 39, "Text"],
Cell[20422, 587, 48, 1, 43, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

